@@ -1,7 +1,9 @@
 import warnings
+from typing import Any, Callable, Optional, Type, Union
 
 import redis
 from redis.sentinel import Sentinel
+from rq.job import Job
 from rq.queue import Queue
 from rq.utils import import_attribute
 
@@ -103,10 +105,10 @@ def get_redis_connection(config, use_strict_redis=False):
         cache = caches[config['USE_REDIS_CACHE']]
         # We're using django-redis-cache
         try:
-            return cache._client
+            return cache._client  # type: ignore[attr-defined]
         except AttributeError:
             # For django-redis-cache > 0.13.1
-            return cache.get_master_client()
+            return cache.get_master_client()  # type: ignore[attr-defined]
 
     if 'UNIX_SOCKET_PATH' in config:
         return redis_cls(unix_socket_path=config['UNIX_SOCKET_PATH'], db=config['DB'])
@@ -138,7 +140,10 @@ def get_redis_connection(config, use_strict_redis=False):
     )
 
 
-def get_connection(name='default', use_strict_redis=False):
+def get_connection(
+    name: str = 'default',
+    use_strict_redis: bool = False,
+) -> redis.Redis:
     """
     Returns a Redis connection to use based on parameters in settings.RQ_QUEUES
     """
@@ -148,16 +153,16 @@ def get_connection(name='default', use_strict_redis=False):
 
 
 def get_queue(
-    name='default',
-    default_timeout=None,
-    is_async=None,
-    autocommit=None,
-    connection=None,
-    queue_class=None,
-    job_class=None,
-    serializer=None,
-    **kwargs
-):
+    name: str = 'default',
+    default_timeout: Optional[int] = None,
+    is_async: Optional[bool] = None,
+    autocommit: Optional[bool] = None,
+    connection: Optional[redis.Redis] = None,
+    queue_class: Optional[Union[str, Type[DjangoRQ]]] = None,
+    job_class: Optional[Union[str, Type[Job]]] = None,
+    serializer: Any = None,
+    **kwargs: Any,
+) -> DjangoRQ:
     """
     Returns an rq Queue using parameters defined in ``RQ_QUEUES``
     """
@@ -280,7 +285,7 @@ def get_queues(*queue_names, **kwargs):
     return queues
 
 
-def enqueue(func, *args, **kwargs):
+def enqueue(func: Callable, *args, **kwargs) -> Job:
     """
     A convenience function to put a job in the default queue. Usage::
 
@@ -333,7 +338,12 @@ try:
 
             return super(DjangoScheduler, self)._create_job(*args, **kwargs)
 
-    def get_scheduler(name='default', queue=None, interval=60):
+    def get_scheduler(
+        name: str = 'default',
+        queue: Optional[DjangoRQ] = None,
+        interval: int = 60,
+        connection: Optional[redis.Redis] = None,
+    ) -> DjangoScheduler:
         """
         Returns an RQ Scheduler instance using parameters defined in
         ``RQ_QUEUES``
@@ -344,14 +354,17 @@ try:
         if isinstance(scheduler_class, str):
             scheduler_class = import_attribute(scheduler_class)
 
+        if connection is None:
+            connection = get_connection(name)
+
         if queue is None:
-            queue = get_queue(name)
+            queue = get_queue(name, connection=connection)
 
         return scheduler_class(
-            queue_name=name, interval=interval, queue=queue, job_class=queue.job_class, connection=get_connection(name)
+            queue_name=name, interval=interval, queue=queue, job_class=queue.job_class, connection=connection
         )
 
 except ImportError:
 
-    def get_scheduler(*args, **kwargs):
+    def get_scheduler(*args, **kwargs):  # type: ignore[misc]
         raise ImproperlyConfigured('rq_scheduler not installed')
