@@ -1,6 +1,7 @@
 import sys
 import datetime
 import time
+from typing import Any, cast, Dict, List
 from unittest import skipIf, mock
 from unittest.mock import patch, PropertyMock, MagicMock
 from uuid import uuid4
@@ -17,6 +18,7 @@ import rq
 from rq.exceptions import NoSuchJobError
 from rq.job import Job
 from rq.registry import FinishedJobRegistry, ScheduledJobRegistry
+from rq.suspension import is_suspended
 from rq.worker import Worker
 from rq.serializers import DefaultSerializer, JSONSerializer
 
@@ -33,7 +35,7 @@ from django_rq.queues import (
 )
 from django_rq import thread_queue
 from django_rq.templatetags.django_rq import force_escape, to_localtime
-from django_rq.tests.fixtures import DummyJob, DummyQueue, DummyWorker
+from django_rq.tests.fixtures import access_self, DummyJob, DummyQueue, DummyWorker
 from django_rq.utils import get_jobs, get_statistics, get_scheduler_pid
 from django_rq.workers import get_worker, get_worker_class
 
@@ -49,10 +51,6 @@ except ImportError:
 QUEUES = settings.RQ_QUEUES
 
 
-def access_self():
-    return get_current_job().id
-
-
 def divide(a, b):
     return a / b
 
@@ -110,7 +108,7 @@ class QueuesTest(TestCase):
     def test_get_connection_default(self):
         """
         Test that get_connection returns the right connection based for
-        `defaut` queue.
+        `default` queue.
         """
         config = QUEUES['default']
         connection = get_connection()
@@ -270,7 +268,7 @@ class QueuesTest(TestCase):
         Checks that passing queues via commandline arguments works
         """
         queue_names = ['django_rq_test', 'django_rq_test2']
-        jobs = []
+        jobs: List[Any] = []
         for queue_name in queue_names:
             queue = get_queue(queue_name)
             jobs.append(
@@ -287,7 +285,7 @@ class QueuesTest(TestCase):
             self.assertIn(job['job'].id, job['finished_job_registry'].get_job_ids())
 
         # Test with rqworker-pool command
-        jobs = []
+        jobs: List[Any] = []
         for queue_name in queue_names:
             queue = get_queue(queue_name)
             jobs.append(
@@ -369,13 +367,13 @@ class QueuesTest(TestCase):
         with self.assertRaises(SystemExit):
             call_command('rqworker', *queue_names, burst=True, sentry_dsn='https://1@sentry.io/1')
 
-    @mock.patch('django_rq.management.commands.rqworker.Connection')
-    def test_connection_error(self, mocked):
-        """Check that redis ConnectionErrors are handled correctly."""
-        mocked.side_effect = ConnectionError("Unable to connect")
-        queue_names = ['django_rq_test']
-        with self.assertRaises(SystemExit):
-            call_command('rqworker', *queue_names)
+    # @mock.patch('django_rq.management.commands.rqworker.Connection')
+    # def test_connection_error(self, mocked):
+    #     """Check that redis ConnectionErrors are handled correctly."""
+    #     mocked.side_effect = ConnectionError("Unable to connect")
+    #     queue_names = ['django_rq_test']
+    #     with self.assertRaises(SystemExit):
+    #         call_command('rqworker', *queue_names)
 
     def test_get_unique_connection_configs(self):
         connection_params_1 = {
@@ -440,8 +438,7 @@ class QueuesTest(TestCase):
         # Make sure old keyword argument 'async' works for backwards
         # compatibility with code expecting older versions of rq or django-rq.
         # Note 'async' is a reserved keyword in Python >= 3.7.
-        kwargs = {'async': False}
-        default_queue_async = get_queue('default', **kwargs)
+        default_queue_async = get_queue('default', **cast(Dict[str, Any], {'async': False}))
         self.assertFalse(default_queue_async._is_async)
 
         # Make sure is_async setting works
@@ -680,8 +677,8 @@ class ThreadQueueTest(TestCase):
         self.assertEqual(queue.count, 0)
 
 
+@skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
 class SchedulerTest(TestCase):
-    @skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
     def test_get_scheduler(self):
         """
         Ensure get_scheduler creates a scheduler instance with the right
@@ -695,7 +692,16 @@ class SchedulerTest(TestCase):
         self.assertEqual(connection_kwargs['port'], config['PORT'])
         self.assertEqual(connection_kwargs['db'], config['DB'])
 
-    @skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
+    def test_get_scheduler_custom_connection(self):
+        """
+        Ensure get_scheduler respects the `connection` argument.
+        """
+
+        with get_connection('test') as connection:
+            scheduler = get_scheduler('test', connection=connection)
+
+            self.assertIs(scheduler.connection, connection)
+
     @patch('django_rq.management.commands.rqscheduler.get_scheduler')
     @patch('django_rq.management.commands.rqscheduler.setup_loghandlers')
     def test_commandline_verbosity_affects_logging_level(self, setup_loghandlers_mock, get_scheduler_mock):
@@ -712,8 +718,7 @@ class SchedulerTest(TestCase):
             setup_loghandlers_mock.assert_called_once_with(expected_level[verbosity])
 
     @override_settings(RQ={'SCHEDULER_CLASS': 'django_rq.tests.fixtures.DummyScheduler'})
-    @skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
-    def test_scheduler_default_timeout(self):
+    def test_scheduler_default(self):
         """
         Scheduler class customization.
         """
@@ -721,7 +726,6 @@ class SchedulerTest(TestCase):
         self.assertIsInstance(scheduler, DummyScheduler)
 
     @override_settings(RQ={'AUTOCOMMIT': True})
-    @skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
     def test_scheduler_default_timeout(self):
         """
         Ensure scheduler respects DEFAULT_RESULT_TTL value for `result_ttl` param.
@@ -733,7 +737,6 @@ class SchedulerTest(TestCase):
         job.delete()
 
     @override_settings(RQ={'AUTOCOMMIT': True, 'DEFAULT_RESULT_TTL': 5432})
-    @skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
     def test_scheduler_default_result_ttl(self):
         """
         Ensure scheduler respects DEFAULT_RESULT_TTL value for `result_ttl` param.
@@ -790,6 +793,15 @@ class JobClassTest(TestCase):
     def test_local_override(self):
         self.assertIs(get_job_class('django_rq.tests.fixtures.DummyJob'), DummyJob)
 
+class SuspendResumeTest(TestCase):
+    def test_suspend_and_resume_commands(self):
+        connection = get_connection()
+        self.assertEqual(is_suspended(connection), 0)
+        call_command('rqsuspend')
+        self.assertEqual(is_suspended(connection), 1)
+        call_command('rqresume')
+        self.assertEqual(is_suspended(connection), 0)
+
 
 class QueueClassTest(TestCase):
     def test_default_queue_class(self):
