@@ -1,6 +1,10 @@
+from typing import cast, Optional, List, Union
+
 from django.core.exceptions import ImproperlyConfigured
 from django.db import connections
+from redis.sentinel import SentinelConnectionPool
 from rq.command import send_stop_job_command
+from rq.executions import Execution
 from rq.job import Job
 from rq.registry import (
     DeferredJobRegistry,
@@ -23,7 +27,7 @@ def get_scheduler_pid(queue):
         It Only works with RQ's Built-in RQScheduler.
         When RQ-Scheduler is available returns False
         If not, it checks the RQ's RQScheduler for a scheduler lock in the desired queue
-        Note: result might have some delay (1-15 minutes) but it helps visualizing whether the setup is working correcly
+        Note: result might have some delay (1-15 minutes) but it helps visualizing whether the setup is working correctly
     '''
     try:
         # first try get the rq-scheduler
@@ -102,8 +106,12 @@ def get_scheduler_statistics():
         # to handle the possibility of a configuration with multiple redis connections and scheduled
         # jobs in more than one of them
         queue = get_queue_by_index(index)
-        connection_kwargs = queue.connection.connection_pool.connection_kwargs
-        conn_key = f"{connection_kwargs['host']}:{connection_kwargs['port']}/{connection_kwargs.get('db', 0)}"
+        if isinstance(queue.connection.connection_pool, SentinelConnectionPool):
+            first_sentinel = queue.connection.connection_pool.sentinel_manager.sentinels[0]
+            connection = first_sentinel.connection_pool.connection_kwargs
+        else:
+            connection = queue.connection.connection_pool.connection_kwargs
+        conn_key = f"{connection['host']}:{connection.get('port', 6379)}/{connection.get('db', 0)}"
         if conn_key not in schedulers:
             try:
                 scheduler = get_scheduler(config['name'])
@@ -116,12 +124,26 @@ def get_scheduler_statistics():
     return {'schedulers': schedulers}
 
 
-def get_jobs(queue, job_ids, registry=None):
+def get_jobs(
+    queue,
+    job_ids,
+    registry: Optional[
+        Union[
+            DeferredJobRegistry,
+            FailedJobRegistry,
+            FinishedJobRegistry,
+            ScheduledJobRegistry,
+            StartedJobRegistry,
+        ]
+    ] = None,
+) -> List[Job]:
     """Fetch jobs in bulk from Redis.
     1. If job data is not present in Redis, discard the result
     2. If `registry` argument is supplied, delete empty jobs from registry
     """
-    jobs = Job.fetch_many(job_ids, connection=queue.connection, serializer=queue.serializer)
+    jobs = cast(
+        List[Optional[Job]], Job.fetch_many(job_ids, connection=queue.connection, serializer=queue.serializer)
+    )
     valid_jobs = []
     for i, job in enumerate(jobs):
         if job is None:
@@ -133,6 +155,20 @@ def get_jobs(queue, job_ids, registry=None):
     return valid_jobs
 
 
+def get_executions(queue, composite_keys: List[str]) -> List[Execution]:
+    """Fetch executions in bulk from Redis.
+    1. If execution data is not present in Redis, discard the result
+    """
+    executions = []
+    for key in composite_keys:
+        job_id, id = key.split(':')
+        try:
+            executions.append(Execution.fetch(id=id, job_id=job_id, connection=queue.connection))
+        except ValueError:
+            pass
+    return executions
+
+
 def stop_jobs(queue, job_ids):
     job_ids = job_ids if isinstance(job_ids, (list, tuple)) else [job_ids]
     stopped_job_ids = []
