@@ -1,6 +1,7 @@
 from __future__ import division
 
 from math import ceil
+from typing import Any
 
 from django.contrib import admin, messages
 from django.contrib.admin.views.decorators import staff_member_required
@@ -25,7 +26,7 @@ from rq.worker_registration import clean_worker_registry
 
 from .queues import get_queue_by_index, get_scheduler_by_index
 from .settings import API_TOKEN, QUEUES_MAP
-from .utils import get_jobs, get_scheduler_statistics, get_statistics, stop_jobs
+from .utils import get_executions, get_jobs, get_scheduler_statistics, get_statistics, stop_jobs
 
 
 @never_cache
@@ -60,7 +61,7 @@ def jobs(request, queue_index):
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
         jobs = queue.get_jobs(offset, items_per_page)
     else:
@@ -91,13 +92,19 @@ def finished_jobs(request, queue_index):
     items_per_page = 100
     num_jobs = len(registry)
     page = int(request.GET.get('page', 1))
+
+    if request.GET.get('desc', '1') == '1':
+        sort_direction = 'descending'
+    else:
+        sort_direction = 'ascending'
+
     jobs = []
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
-        job_ids = registry.get_job_ids(offset, offset + items_per_page - 1)
+        job_ids = registry.get_job_ids(offset, offset + items_per_page - 1, desc=sort_direction == 'descending')
         jobs = get_jobs(queue, job_ids, registry)
 
     else:
@@ -111,9 +118,9 @@ def finished_jobs(request, queue_index):
         'num_jobs': num_jobs,
         'page': page,
         'page_range': page_range,
-        'job_status': 'Finished',
+        'sort_direction': sort_direction,
     }
-    return render(request, 'django_rq/jobs.html', context_data)
+    return render(request, 'django_rq/finished_jobs.html', context_data)
 
 
 @never_cache
@@ -127,13 +134,19 @@ def failed_jobs(request, queue_index):
     items_per_page = 100
     num_jobs = len(registry)
     page = int(request.GET.get('page', 1))
+
+    if request.GET.get('desc', '1') == '1':
+        sort_direction = 'descending'
+    else:
+        sort_direction = 'ascending'
+
     jobs = []
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
-        job_ids = registry.get_job_ids(offset, offset + items_per_page - 1)
+        job_ids = registry.get_job_ids(offset, offset + items_per_page - 1, desc=sort_direction == 'descending')
         jobs = get_jobs(queue, job_ids, registry)
 
     else:
@@ -147,9 +160,9 @@ def failed_jobs(request, queue_index):
         'num_jobs': num_jobs,
         'page': page,
         'page_range': page_range,
-        'job_status': 'Failed',
+        'sort_direction': sort_direction,
     }
-    return render(request, 'django_rq/jobs.html', context_data)
+    return render(request, 'django_rq/failed_jobs.html', context_data)
 
 
 @never_cache
@@ -167,13 +180,13 @@ def scheduled_jobs(request, queue_index):
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
         job_ids = registry.get_job_ids(offset, offset + items_per_page - 1)
 
         jobs = get_jobs(queue, job_ids, registry)
         for job in jobs:
-            job.scheduled_at = registry.get_scheduled_time(job)
+            job.scheduled_at = registry.get_scheduled_time(job)  # type: ignore[attr-defined]
 
     else:
         page_range = []
@@ -203,13 +216,15 @@ def started_jobs(request, queue_index):
     num_jobs = len(registry)
     page = int(request.GET.get('page', 1))
     jobs = []
+    executions = []
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
         job_ids = registry.get_job_ids(offset, offset + items_per_page - 1)
         jobs = get_jobs(queue, job_ids, registry)
+        executions = get_executions(queue, job_ids)
 
     else:
         page_range = []
@@ -223,8 +238,9 @@ def started_jobs(request, queue_index):
         'page': page,
         'page_range': page_range,
         'job_status': 'Started',
+        'executions': executions,
     }
-    return render(request, 'django_rq/jobs.html', context_data)
+    return render(request, 'django_rq/started_job_registry.html', context_data)
 
 
 @never_cache
@@ -252,7 +268,7 @@ def worker_details(request, queue_index, key):
     queue = get_queue_by_index(queue_index)
     worker = Worker.find_by_key(key, connection=queue.connection)
     # Convert microseconds to milliseconds
-    worker.total_working_time = worker.total_working_time / 1000
+    worker.total_working_time = worker.total_working_time / 1000  # type: ignore[assignment]
 
     queue_names = ', '.join(worker.queue_names())
 
@@ -283,7 +299,7 @@ def deferred_jobs(request, queue_index):
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
         job_ids = registry.get_job_ids(offset, offset + items_per_page - 1)
 
@@ -330,7 +346,7 @@ def job_detail(request, queue_index, job_id):
     rv = job.connection.hget(job.key, 'result')
     if rv is not None:
         # cache the result
-        job.legacy_result = job.serializer.loads(rv)
+        job.legacy_result = job.serializer.loads(rv)  # type: ignore[attr-defined]
     try:
         exc_info = job._exc_info
     except AttributeError:
@@ -403,7 +419,12 @@ def clear_queue(request, queue_index):
             queue.empty()
             messages.info(request, 'You have successfully cleared the queue %s' % queue.name)
         except ResponseError as e:
-            if 'EVALSHA' in e.message:
+            try:
+                suppress = 'EVALSHA' in e.message  # type: ignore[attr-defined]
+            except AttributeError:
+                suppress = 'EVALSHA' in str(e)
+
+            if suppress:
                 messages.error(
                     request,
                     'This action is not supported on Redis versions < 2.6.0, please use the bulk delete command instead',
@@ -528,9 +549,9 @@ def actions(request, queue_index):
                 messages.info(request, 'You have successfully requeued %d  jobs!' % len(job_ids))
             elif request.POST['action'] == 'stop':
                 stopped, failed_to_stop = stop_jobs(queue, job_ids)
-                if len(stopped) >0 :
+                if len(stopped) > 0:
                     messages.info(request, 'You have successfully stopped %d jobs!' % len(stopped))
-                if len(failed_to_stop) >0 :
+                if len(failed_to_stop) > 0:
                     messages.error(request, '%d jobs failed to stop!' % len(failed_to_stop))
 
     return redirect(next_url)
@@ -553,6 +574,7 @@ def enqueue_job(request, queue_index, job_id):
             queue.enqueue_job(job)
 
         # Remove job from correct registry if needed
+        registry: Any
         if job.get_status() == JobStatus.DEFERRED:
             registry = DeferredJobRegistry(queue.name, queue.connection)
             registry.remove(job)
@@ -603,7 +625,7 @@ def scheduler_jobs(request, scheduler_index):
 
     if num_jobs > 0:
         last_page = int(ceil(num_jobs / items_per_page))
-        page_range = range(1, last_page + 1)
+        page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
         jobs_times = scheduler.get_jobs(with_times=True, offset=offset, length=items_per_page)
         for job, time in jobs_times:
